==> tdeaddons-R14.0.0-x86_64-ifx.txz: install/doinst.sh <==
( cd usr/share/doc/tde/HTML/en/kate-plugins ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kate-plugins ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kicker-applets ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kicker-applets ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/babel ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/babel ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/crashes ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/crashes ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/dirfilter ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/dirfilter ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/domtreeviewer ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/domtreeviewer ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/fsview ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/fsview ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/imgallery ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/imgallery ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/khtmlsettings ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/khtmlsettings ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/kuick ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/kuick ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/mediaplayer ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/mediaplayer ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/uachanger ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/uachanger ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/validators ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/validators ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/webarchiver ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/webarchiver ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/ksig ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/ksig ; ln -sf /usr/share/doc/tde/HTML/en/common common )

==> tdeaddons-14.0.9-x86_64-ifx.txz: install/doinst.sh <==

# Update the desktop database:
/usr/bin/update-desktop-database ./usr/share/applications

# Update hicolor theme cache:
/usr/bin/gtk-update-icon-cache -f -t ./usr/share/icons/hicolor

# Update the mime database:
/usr/bin/update-mime-database -Vn usr/share/mime

( cd usr/share/doc/tde/HTML/en/atlantikdesigner ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/atlantikdesigner ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kate-plugins ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kate-plugins ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/khelpcenter/docprimer ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/khelpcenter/docprimer ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/khelpcenter/markup ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/khelpcenter/markup ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/khelpcenter/styleguide ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/khelpcenter/styleguide ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kicker-applets ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kicker-applets ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/babel ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/babel ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/crashes ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/crashes ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/dirfilter ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/dirfilter ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/domtreeviewer ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/domtreeviewer ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/fsview ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/fsview ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/imgallery ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/imgallery ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/kuick ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/kuick ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/mediaplayer ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/mediaplayer ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/rsync ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/rsync ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/tdehtmlsettings ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/tdehtmlsettings ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/uachanger ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/uachanger ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/validators ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/validators ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/webarchiver ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/konq-plugins/webarchiver ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/ksig ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/ksig ; ln -sf /usr/share/doc/tde/HTML/en/common common )
